<?php
/**
 *
 * Plugin	CKEditor 
 * @author	Stephane F, Thomas Ingles #PHP edition
 *
 **/

class ckeditor extends plxPlugin {

	public $valid_path = false;
	public $lang;
	public $racine;

	/**
	 * Constructeur de la classe ckeditor
	 *
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	null
	 * @authors	Stephane F
	 **/
	public function __construct($default_lang) {

		if(defined('PLX_ADMIN')) {

			# Appel du constructeur de la classe plxPlugin (obligatoire)
			parent::__construct($default_lang);

			$this->lang = $default_lang;

			# droits pour accéder à la page config.php du plugin
			$this->setConfigProfil(PROFIL_ADMIN);
 
			$this->addHook('AdminTopBottom', 'AdminTopBottom');
 
			$this->valid_path = is_dir(PLX_ROOT.($this->getParam("folder")));
			if($this->valid_path) {
 
				# répertoire racine d'installation de PluXml sur le serveur pour roxy file manager, Abs2Rel et Rel2Abs
				$dir = str_replace("\\", "/", dirname($_SERVER["SCRIPT_NAME"]));
				$this->racine = trim(preg_replace("/\/(core|plugins)\/(.*)/", "", $dir), "/")."/";
				$this->racine = $this->racine[0]!="/" ? "/".$this->racine : $this->racine;
 
				# déclaration pour ajouter l'éditeur
				$static = $this->getParam('static')==1 ? '' : '|statique';
				if(!preg_match('/(medias|parametres_edittpl|comment'.$static.')/', basename($_SERVER['SCRIPT_NAME']))) {
					$this->addHook('AdminTopEndHead', 'AdminTopEndHead');
					$this->addHook('AdminFootEndBody', 'AdminFootEndBody');
				}
 
				if(!isset($_POST['new_category'])) {
					# conversion des liens abs/rel dans les articles et les pages statiques
					$this->addHook('plxAdminEditArticle', 'Abs2Rel');
					$this->addHook('plxAdminEditStatique', 'Abs2Rel');
					# conversion des liens rel/abs dans les articles et les pages statiques
					$this->addHook('AdminArticleTop', 'Rel2Abs');
					$this->addHook('AdminStaticTop', 'Rel2Abs');

				}
			}
		}
	}

	/**
	 * Méthode qui affiche un message si le répertoire de stockage des fichiers n'est pas définit dans la config du plugin
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function AdminTopBottom() {

		$string = '
		if($plxAdmin->plxPlugins->aPlugins["'.__CLASS__.'"]->getParam("folder")=="") {
			echo "<p class=\"warning\">Plugin '.__CLASS__.'<br />'.$this->getLang("L_ERR_FOLDER_NOT_DEFINED").'</p>";
			plxMsg::Display();
		} elseif(!$plxAdmin->plxPlugins->aPlugins["'.__CLASS__.'"]->valid_path) {
			echo "<p class=\"warning\">Plugin '.__CLASS__.'<br />'.$this->getLang("L_ERR_FOLDER_INVALID_DIR").'</p>";
			plxMsg::Display();
		}';
		echo '<?php '.$string.' ?>';

	}

	/**
	 * Méthode qui ajoute la déclaration du script javascript de ckeditor dans la partie <head>
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function AdminTopEndHead() {

		$plxAdmin = plxAdmin::getinstance();
		$_SESSION['FILEMAN_FILES_ROOT'] = $this->racine.trim($this->getParam('folder'), "/");
		if($plxAdmin->aConf['userfolders'] AND $_SESSION['profil']==PROFIL_WRITER) {
			$_SESSION['FILEMAN_FILES_ROOT'] .= "/".$_SESSION['user'];
		}

	}

	/**
	 * Méthode qui ajoute la déclaration du script javascript de ckeditor en bas de page
	 *
	 * @return	stdio
	 * @author	Stephane F, Thomas Ingles
	 **/
	public function AdminFootEndBody() {

		$extra = trim($this->getParam('extraPlugins'));
		$extraPlugins = ($extra !='' ? ','.$extra : '');
		$extraPlugins = str_replace(' ', '', $extraPlugins);
		$height = trim($this->getParam('height'));
		if($height!='') $height = 'height:'.(is_numeric($height) ? $height : '"'.$height.'"').',';

?>
<script>
<!--
if(typeof CKEDITOR != 'undefined') {
	var is_modified = 0;
	var editor = new Array();
	var roxyFileman = '<?php echo PLX_PLUGINS.__CLASS__ ?>/fileman/index.html?integration=ckeditor';
	var textareas = document.getElementsByTagName("textarea");
	for(var i=0;i<textareas.length;i++) {
		var n = textareas[i].name;
		if(n=="content" || n=="chapo") {

			editor[i] = CKEDITOR.replace('id_'+n, {
				extraPlugins: 'save,autosave,codemirror,uploadimage,justify,showblocks,embed,embedbase,lineutils,widgetselection,widget,notification,notificationaggregator,toolbar<?php echo $extraPlugins ?>',
				<?php echo $height ?>
//				scayt_autoStartup: true,
				extraAllowedContent: 'video[*]{*}',
				filebrowserBrowseUrl: roxyFileman,
				filebrowserImageBrowseUrl: roxyFileman+'&type=image',
//				removeDialogTabs: 'link:upload;image:upload',
<?php
				$ckid = explode(DIRECTORY_SEPARATOR,$_SERVER['REQUEST_URI']);//
				$ckid = str_replace(array('.php','?','=','&'),'',end($ckid));//
				$ckid .= isset($_POST['new_category']) ? 'a'.@$_GET['a'] : '';//for new cat (in article)
?>
				autosave_SaveKey: 'ckautosaveKey_'+i+'_<?php echo $this->lang.'_'.$ckid ?>',

				imageUploadUrl: '<?php echo PLX_PLUGINS.__CLASS__ ?>/ajax_upload.php?type=Images',

				entities: false,
				allowedContent: true,
				language: '<?php echo $this->default_lang ?>',
			});

			// The "change" event is fired whenever a change is made in the editor.
			editor[i].on( 'change', function( evt ) {
				if(is_modified) return;
				is_modified = 1;
				// getData() returns CKEditor's HTML content.
				//console.log( 'Total bytes: ' + evt.editor.getData().length );
			});

		}
	}

//Fix : on save normal event call (button)
	var inputs = document.getElementsByTagName('input');//
	for (var j = 0; j < inputs.length; j++) {
		if (inputs[j].getAttribute('type') == 'submit') {
			if(inputs[j].name != 'preview')
				inputs[j].onclick = function (ev){this.form.target = '_self';is_modified = 0;return true;};
		}
	}

	window.onbeforeunload = function (ev){
  console.log('ck onbeforeunload',ev);
		if (is_modified)
			return "Your change has not been sent or saved, and will be lost if you leave this page.";
	}

}
-->
</script>
<?php
//extraAllowedContent: 'video[*]{*};source[*]{*}',
	}

	/**
	 * Méthode qui convertit les liens absolus en liens relatifs
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function Abs2Rel() {

		echo '<?php '; ?>

		# Préparation des variables
		$abs_path_images = "<?php echo $this->racine.$this->getParam('folder')?>";
		$rel_path_images = "<?php echo $this->getParam('folder')?>";

		# Les liens absolus commençant par http://www.domaine.com/ sont convertis en liens relatifs
		if(isset($content["chapo"])) {
			$content["chapo"] = str_replace($abs_path_images, $rel_path_images, $content["chapo"]);
		}
		$content["content"] = str_replace($abs_path_images, $rel_path_images, $content["content"]);

		?><?php

	}

	/**
	 * Méthode qui convertit les liens relatifs en liens absolus
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function Rel2Abs() {

		echo '<?php '; ?>

		if(!isset($_POST["draft"]) AND !isset($_POST["publish"]) AND !isset($_POST["update"]) AND !isset($_POST["moderate"])) {
			# Préparation des variables
			$abs_path_images = "<?php echo $this->racine.$this->getParam('folder')?>";
			$rel_path_images = "<?php echo $this->getParam('folder')?>";

			# Les liens relatifs sont convertis en liens absolus, pour que les images soient visibles dans CKEditor
			if(isset($chapo)) {
				$chapo = str_replace($rel_path_images, $abs_path_images, $chapo);
			}
			$content = str_replace($rel_path_images, $abs_path_images, $content);
		}

		?><?php
		echo '<script src="'.PLX_PLUGINS.__CLASS__.'/ckeditor-4.11.1_PHP/ckeditor.js"></script>'."\n";
		echo "<style>.cke_dialog_contents tr:hover { background-color: #fff; }</style>\n";
	}

}
?>
